This is a collection of useful tools for analytics, statistics and data science. At the moment, only test modules are available:
- calculator
- statistical_tools

# Installation

```
pip install dreamtim
```

# Usage

```python
from dreamtim.calculator import Calculator

calc_obj = Calculator(5)
calc_obj.add(3)
# returns 8.0
```

For complete documentation, please, check this page:
https://ryko.tk/dreamtim/
